# Medium multiply
A small demo library for a Medium publication about publishing libraries.

### Installation
```
pip install medium-multiply
```

### Get started
How to multiply one number by another with this lib:

```Python
from medium_multiply import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)
```